@@ -10,7 +10,6 @@ except ImportError:
     print("http://rauth.readthedocs.org/en/latest/\n")
 
 
-
 class QuickBooks(object):
     """A wrapper class around Python's Rauth module for Quickbooks the API"""
 
@@ -79,6 +78,9 @@ class QuickBooks(object):
 
         return QuickBooks.__instance
 
+    def _drop(self):
+        QuickBooks.__instance = None
+
     @property
     def api_url(self):
         if self.sandbox:
@@ -153,7 +155,11 @@ class QuickBooks(object):
         }
 
         req = self.session.request(request_type, url, True, self.company_id, headers=headers, data=request_body)
-        result = req.json()
+
+        try:
+            result = req.json()
+        except:
+            raise QuickbooksException("Error reading json response", 10000, "")
 
         if req.status_code is not httplib.OK or "Fault" in result:
             self.handle_exceptions(result["Fault"])
