@@ -1,4 +1,4 @@
-from base import QuickbooksBaseObject, Ref, QuickbooksManagedObject
+from base import QuickbooksBaseObject, Ref, QuickbooksManagedObject, QuickbooksTransactionEntity
 from tax import TxnTaxDetail
 
 
@@ -12,6 +12,9 @@ class JournalEntryLineDetail(QuickbooksBaseObject):
         self.PostingType = ""
         self.AccountRef = None
 
+    def __unicode__(self):
+        return self.PostingType
+
 
 class JournalEntryLine(QuickbooksBaseObject):
     class_dict = {
@@ -24,8 +27,11 @@ class JournalEntryLine(QuickbooksBaseObject):
         self.Amount = 0
         self.DetailType = ""
 
+    def __unicode__(self):
+        return str(self.Amount)
 
-class JournalEntry(QuickbooksManagedObject):
+
+class JournalEntry(QuickbooksManagedObject, QuickbooksTransactionEntity):
     """
     QBO definition: Journal Entry is a transaction in which:
         - There are at least two parts - a Debit and a Credit - called distribution lines.
@@ -50,3 +56,6 @@ class JournalEntry(QuickbooksManagedObject):
         super(JournalEntry, self).__init__()
         self.Adjustment = False
         self.TxnDate = ""
+
+    def __unicode__(self):
+        return str(self.Adjustment)
