@@ -1,7 +1,7 @@
-from base import QuickbooksBaseObject
+from base import QuickbooksManagedObject
 
 
-class TaxAgency(QuickbooksBaseObject):
+class TaxAgency(QuickbooksManagedObject):
     """
     QBO definition: Tax Agency is an entity that is associated with a tax rate and identifies the agency to which that tax rate
     applies, that is, the entity that collects those taxes.
@@ -12,6 +12,7 @@ class TaxAgency(QuickbooksBaseObject):
     qbo_object_name = "TaxAgency"
 
     def __init__(self):
+        super(TaxAgency, self).__init__()
         self.DisplayName = ""
         self.TaxTrackedOnSales = True
         self.TaxTrackedOnPurchases = False
